[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,78 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/stream/interfaces/slice_reduction_ops.cuh>
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
__global__ void add(int* ptr, int value)
|
||||
{
|
||||
*ptr = *ptr + value;
|
||||
}
|
||||
|
||||
__global__ void check_val(const int* ptr, int expected)
|
||||
{
|
||||
assert(*ptr == expected);
|
||||
}
|
||||
|
||||
/*
|
||||
* This test ensures that we can reconstruct a piece of data where there are
|
||||
* multiple "shared" instances, and "redux" instances
|
||||
*/
|
||||
int main()
|
||||
{
|
||||
stream_ctx ctx;
|
||||
|
||||
int ndevs;
|
||||
cuda_safe_call(cudaGetDeviceCount(&ndevs));
|
||||
|
||||
if (ndevs < 2)
|
||||
{
|
||||
fprintf(stderr, "Skipping test: need at least 2 devices.\n");
|
||||
return 0;
|
||||
}
|
||||
|
||||
auto redux_op = std::make_shared<slice_reduction_op_sum<int>>();
|
||||
|
||||
int a = 17;
|
||||
|
||||
// init op (17)
|
||||
auto handle = ctx.logical_data(make_slice(&a, 1));
|
||||
|
||||
// RW dev0 (18)
|
||||
ctx.task(exec_place::device(0), handle.rw())->*[](auto stream, auto s) {
|
||||
add<<<1, 1, 0, stream>>>(s.data_handle(), 1);
|
||||
};
|
||||
|
||||
// READ dev1 (18)
|
||||
ctx.task(exec_place::device(1), handle.read())->*[](auto stream, auto s) {
|
||||
check_val<<<1, 1, 0, stream>>>(s.data_handle(), 18);
|
||||
};
|
||||
|
||||
// REDUX dev1 (18 + 42)
|
||||
ctx.task(exec_place::device(1), handle.relaxed(redux_op))->*[](auto stream, auto s) {
|
||||
add<<<1, 1, 0, stream>>>(s.data_handle(), 42);
|
||||
};
|
||||
|
||||
// READ dev0 (18 + 42)
|
||||
ctx.task(exec_place::device(0), handle.read())->*[](auto stream, auto s) {
|
||||
check_val<<<1, 1, 0, stream>>>(s.data_handle(), 18 + 42);
|
||||
};
|
||||
|
||||
// READ
|
||||
ctx.task(exec_place::host(), handle.read())->*[](auto stream, auto s) {
|
||||
cuda_safe_call(cudaStreamSynchronize(stream));
|
||||
EXPECT(s(0) == 18 + 42);
|
||||
// printf("VALUE %d expected %d\n", s(0), 18 + 42);
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
Reference in New Issue
Block a user